summaryrefslogtreecommitdiffstats
path: root/base/path_service.cc
diff options
context:
space:
mode:
authorrvargas@google.com <rvargas@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-19 23:20:09 +0000
committerrvargas@google.com <rvargas@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-19 23:20:09 +0000
commitaa443bbd00b53fe0701de2ca18e4f5f3acf5c25c (patch)
tree69e61525cec8890ee6cd1612e841ef661f1f1587 /base/path_service.cc
parenta94a03acc534fa15a278f4b6ed8f3cba8a737679 (diff)
downloadchromium_src-aa443bbd00b53fe0701de2ca18e4f5f3acf5c25c.zip
chromium_src-aa443bbd00b53fe0701de2ca18e4f5f3acf5c25c.tar.gz
chromium_src-aa443bbd00b53fe0701de2ca18e4f5f3acf5c25c.tar.bz2
Revert 56738 - Fix CheckFalseTest.CheckFails on Linux after my change to ui_test.
This makes PathService clear its cache after overriding a path. We have many paths depending on each other, so this is necessary to avoid inconsistencies. TEST=ui_tests in Release mode BUG=49838 Review URL: http://codereview.chromium.org/2805100 TBR=phajdan.jr@chromium.org Review URL: http://codereview.chromium.org/3169031 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@56778 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'base/path_service.cc')
-rw-r--r--base/path_service.cc45
1 files changed, 13 insertions, 32 deletions
diff --git a/base/path_service.cc b/base/path_service.cc
index ee94c16..57cbc33 100644
--- a/base/path_service.cc
+++ b/base/path_service.cc
@@ -31,6 +31,7 @@ namespace base {
namespace {
typedef base::hash_map<int, FilePath> PathMap;
+typedef base::hash_set<int> PathSet;
// We keep a linked list of providers. In a debug build we ensure that no two
// providers claim overlapping keys.
@@ -93,8 +94,8 @@ static Provider base_provider_posix = {
struct PathData {
Lock lock;
- PathMap cache; // Cache mappings from path key to path value.
- PathMap overrides; // Track path overrides.
+ PathMap cache; // Track mappings from path key to path value.
+ PathSet overrides; // Track whether a path has been overridden.
Provider* providers; // Linked list of path service providers.
PathData() {
@@ -140,20 +141,6 @@ bool PathService::GetFromCache(int key, FilePath* result) {
}
// static
-bool PathService::GetFromOverrides(int key, FilePath* result) {
- PathData* path_data = GetPathData();
- AutoLock scoped_lock(path_data->lock);
-
- // check for an overriden version.
- PathMap::const_iterator it = path_data->overrides.find(key);
- if (it != path_data->overrides.end()) {
- *result = it->second;
- return true;
- }
- return false;
-}
-
-// static
void PathService::AddToCache(int key, const FilePath& path) {
PathData* path_data = GetPathData();
AutoLock scoped_lock(path_data->lock);
@@ -175,15 +162,8 @@ bool PathService::Get(int key, FilePath* result) {
if (key == base::DIR_CURRENT)
return file_util::GetCurrentDirectory(result);
- if (GetFromCache(key, result)) {
- LOG(ERROR) << "Key: " << key << " returning " << result->value() << " from cache.";
+ if (GetFromCache(key, result))
return true;
- }
-
- if (GetFromOverrides(key, result)) {
- LOG(ERROR) << "Key: " << key << " returning " << result->value() << " from overrides.";
- return true;
- }
FilePath path;
@@ -204,7 +184,6 @@ bool PathService::Get(int key, FilePath* result) {
AddToCache(key, path);
*result = path;
- LOG(ERROR) << "Key: " << key << " returning " << result->value() << ".";
return true;
}
@@ -220,6 +199,14 @@ bool PathService::Get(int key, std::wstring* result) {
}
#endif
+bool PathService::IsOverridden(int key) {
+ PathData* path_data = GetPathData();
+ DCHECK(path_data);
+
+ AutoLock scoped_lock(path_data->lock);
+ return path_data->overrides.find(key) != path_data->overrides.end();
+}
+
bool PathService::Override(int key, const FilePath& path) {
PathData* path_data = GetPathData();
DCHECK(path_data);
@@ -241,14 +228,8 @@ bool PathService::Override(int key, const FilePath& path) {
return false;
AutoLock scoped_lock(path_data->lock);
-
- // Clear the cache now. Some of its entries could have depended
- // on the value we are overriding, and are now out of sync with reality.
- path_data->cache.clear();
-
path_data->cache[key] = file_path;
- path_data->overrides[key] = file_path;
-
+ path_data->overrides.insert(key);
return true;
}